#
# spec file for package kio-fuse
#
# Copyright (c) 2021 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%bcond_without lang
Name:           kio-fuse
Version:        5.0.1
Release:        bp155.3.6
Summary:        Access KIO over the regular filesystem
License:        GPL-3.0-or-later
Group:          System/GUI/KDE
URL:            https://www.kde.org
Source0:        https://download.kde.org/stable/%{name}/%{version}/%{name}-%{version}.tar.xz
%if %{with lang}
Source1:        https://download.kde.org/stable/%{name}/%{version}/%{name}-%{version}.tar.xz.sig
Source2:        kio-fuse.keyring
%endif
# PATCH-FIX-UPSTREAM
Patch1:         0001-Initialize-m_lastChildrenRefresh-to-be-really-in-the.patch
BuildRequires:  extra-cmake-modules
BuildRequires:  pkgconfig
BuildRequires:  cmake(KF5KIO) >= 5.66.0
BuildRequires:  cmake(Qt5DBus) >= 5.12.0
BuildRequires:  cmake(Qt5Test)
BuildRequires:  pkgconfig(fuse3)
Requires:       fuse3
# For %%check
BuildRequires:  kio-extras5
# While kio itself can make use of this, it's most likely used through dolphin
Supplements:    dolphin

%description
kio-fuse is a daemon which makes KIO URLs accessible to KIO unaware
applications using FUSE.

%prep
%autosetup -p1

%build
%cmake_kf5 -d build -- -DBUILD_TESTING=ON
%cmake_build

%install
%kf5_makeinstall -C build

%if %{pkg_vcmp util-linux >= 2.34}
%check
# The hack below only works with util-linux 3.34+.
# Without working umount, the tests can't work :-(

ret=0
fusermount3 || ret=$?
if [ $ret -eq 126 ] ; then
  # No permission to run fusermount3: boo#1159963
  exit 0
fi

# Hack to make "fusermount3 -u" work in the OBS context
# (https://github.com/openSUSE/obs-build/issues/535)
echo -e '#!/bin/sh\numount $2' >> fusermount3
chmod a+x fusermount3
export PATH=$PWD:$PATH

export CTEST_OUTPUT_ON_FAILURE=1
make %{?_smp_mflags} -C build VERBOSE=1 test
%endif

%files
%license LICENSES/*
%{_kf5_sharedir}/dbus-1/services/org.kde.KIOFuse.service
%{_libexecdir}/kio-fuse
%{_tmpfilesdir}/kio-fuse-tmpfiles.conf
%{_userunitdir}/kio-fuse.service

%changelog
* Mon Mar  7 2022 Christophe Giboudeaux <christophe@krop.fr>
- Replace %%_libdir/libexec with %%_libexecdir (boo#1174075)
* Thu Jun  3 2021 Fabian Vogt <fabian@ritter-vogt.de>
- Use %%pkg_vcmp for util-linux requirement for %%check
- Add patch to avoid occasional test failure:
  * 0001-Initialize-m_lastChildrenRefresh-to-be-really-in-the.patch
* Sun Mar 21 2021 Fabian Vogt <fabian@ritter-vogt.de>
- Update to version 5.0.1:
  * Changes to a directory while iterating it (opendir/readdir) don't break the
    iteration anymore
  * Some ioslaves with incompatible behaviour (they claim "/" is a regular file)
    are rejected now. Previously, mounting those succeeded, but accessing files
    failed. Now mounting fails immediately and the fallback code is triggered.
  * Mixup of UDS_URL/UDS_TARGET_URL got fixed. Now the baloosearch:/ protocol
    works and doesn't cause a crash anymore. Additionally, the relevant code got
    hardened.
- Install by default: supplement dolphin
* Sat Dec 26 2020 Fabian Vogt <fabian@ritter-vogt.de>
- Update to version 5.0.0:
  * Symlinks with an absolute target path are "rewritten" to point to the
    location inside the target instead of the host system
  * Mounting a URL which includes symlinks now works
  * Quite a bit of refactoring and cleanup, also for ^
  * The DBus service can use systemd activation now
* Thu Aug 27 2020 Christophe Giboudeaux <christophe@krop.fr>
- Spec cleanup
* Tue May 26 2020 Fabian Vogt <fabian@ritter-vogt.de>
- Update to version 4.95.0:
  * Use of KIO::FileJob to write and read without downloading the whole file
  * Expiring local nodes so that changes on the remote side become visible
    (the local cache is valid for at most 30s)
  * New DBus API to map a FUSE path back to a remote URL, used for syncing the
    terminal panel in dolphin to the main view (needs Dolphin from git master)
  * Minimum version of Qt got raised to 5.12
  * Minimum version of KIO got raised to 5.66 (needed for KIO::FileJob)
  * Builds with CMake < 3.13 again
- Drop patches, now upstream:
  * 0001-Use-target_link_libraries-instead-of-target_link_opt.patch
* Tue Dec 31 2019 Fabian Vogt <fabian@ritter-vogt.de>
- Skip %%check if fusermount3 is not executable. post-build-checks
  breaks it in openSUSE:Factory (boo#1159963)
* Fri Nov 29 2019 Fabian Vogt <fabian@ritter-vogt.de>
- Initial commit
